summaryrefslogtreecommitdiff
path: root/chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2017-03-08 10:28:10 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2017-03-20 13:40:30 +0000
commite733310db58160074f574c429d48f8308c0afe17 (patch)
treef8aef4b7e62a69928dbcf880620eece20f98c6df /chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h
parent2f583e4aec1ae3a86fa047829c96b310dc12ecdf (diff)
downloadqtwebengine-chromium-e733310db58160074f574c429d48f8308c0afe17.tar.gz
BASELINE: Update Chromium to 56.0.2924.122
Change-Id: I4e04de8f47e47e501c46ed934c76a431c6337ced Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h')
-rw-r--r--chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h25
1 files changed, 9 insertions, 16 deletions
diff --git a/chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h b/chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h
index 6cebf181561..19552c954c6 100644
--- a/chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h
+++ b/chromium/third_party/WebKit/Source/core/origin_trials/OriginTrialContext.h
@@ -23,13 +23,13 @@ class WebTrialTokenValidator;
// to check if the experimental feature should be enabled for the current
// context. This class is not for direct use by feature implementers.
// Instead, the OriginTrials generated namespace provides a method for each
// feature to check if it is enabled. Experimental features must be defined in
// RuntimeEnabledFeatures.in, which is used to generate OriginTrials.h/cpp.
//
// Experimental features are defined by string names, provided by the
// implementers. The framework does not maintain an enum or constant list for
// feature names. Instead, the name provided by the feature implementation
// is validated against any provided tokens.
//
// For more information, see https://github.com/jpchase/OriginTrials.
class CORE_EXPORT OriginTrialContext final
@@ -66,9 +66,9 @@ class CORE_EXPORT OriginTrialContext final
void addToken(const String& token);
void addTokens(const Vector<String>& tokens);
- // Returns true if the feature should be considered enabled for the current
- // execution context.
- bool isFeatureEnabled(const String& featureName);
+ // Returns true if the trial (and therefore the feature or features it
+ // controls) should be considered enabled for the current execution context.
+ bool isTrialEnabled(const String& trialName);
// Installs JavaScript bindings on the Window object for any features which
// should be enabled by the current set of trial tokens. This method is called
@@ -78,9 +78,6 @@ class CORE_EXPORT OriginTrialContext final
// without doing anything.
void initializePendingFeatures();
- void setFeatureBindingsInstalled(const String& featureName);
- bool featureBindingsInstalled(const String& featureName);
-
DECLARE_VIRTUAL_TRACE();
private:
@@ -88,12 +85,8 @@ class CORE_EXPORT OriginTrialContext final
Member<ExecutionContext> m_host;
Vector<String> m_tokens;
- HashSet<String> m_enabledFeatures;
+ HashSet<String> m_enabledTrials;
WebTrialTokenValidator* m_trialTokenValidator;
-
- // Records whether a feature has been installed into the host's V8 context,
- // for each feature name.
- HashSet<String> m_bindingsInstalled;
};
} // namespace blink
@@ -23,13 +23,13 @@ class WebTrialTokenValidator;
// context. This class is not for direct use by feature implementers.
// Instead, the OriginTrials generated namespace provides a method for each
-// feature to check if it is enabled. Experimental features must be defined in
+// trial to check if it is enabled. Experimental features must be defined in
// RuntimeEnabledFeatures.in, which is used to generate OriginTrials.h/cpp.
//
@@ -23,13 +23,13 @@ class WebTrialTokenValidator;
// RuntimeEnabledFeatures.in, which is used to generate OriginTrials.h/cpp.
//
-// Experimental features are defined by string names, provided by the
-// implementers. The framework does not maintain an enum or constant list for
-// feature names. Instead, the name provided by the feature implementation
-// is validated against any provided tokens.
+// Origin trials are defined by string names, provided by the implementers. The
+// framework does not maintain an enum or constant list for trial names.
+// Instead, the name provided by the feature implementation is validated against
+// any provided tokens.
//
// For more information, see https://github.com/jpchase/OriginTrials.